@@ -579,6 +579,15 @@ class Factura(object):
         else:
             return False
 
+    @property
+    def mediaconsumo(self):
+        tree = 'mediaconsumo'
+        data = get_rec_attr(self.obj, tree, False)
+        if data is not None and data is not False:
+            return MediaConsumo(data)
+        else:
+            return False
+
     @property
     def codtbai(self):
         tree = 'codtbai'
@@ -1587,6 +1596,29 @@ class Imputacioncostes(object):
             return False
 
 
+class MediaConsumo(object):
+    def __init__(self, data):
+        self.obj = data
+
+    @property
+    def mediaconsperiodofact5A(self):
+        tree = 'mediaconsperiodofact5A'
+        data = get_rec_attr(self.obj, tree, False)
+        if data is not None and data is not False:
+            return data.text
+        else:
+            return False
+
+    @property
+    def mediaconsperiodofact(self):
+        tree = 'mediaconsperiodofact'
+        data = get_rec_attr(self.obj, tree, False)
+        if data is not None and data is not False:
+            return data.text
+        else:
+            return False
+
+
 # Datos para B7032
 class B7032(B7031):
     pass
